;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "mistty" "20250716.1914"
  "Shell/Comint alternative based on term.el."
  '((emacs "29.1"))
  :url "http://github.com/szermatt/mistty"
  :commit "bfb17611cff6c845270050a0756a38489cdf4ed6"
  :revdesc "bfb17611cff6"
  :keywords '("convenience" "unix")
  :authors '(("Stephane Zermatten" . "szermatt@gmx.net"))
  :maintainers '(("Stephane Zermatten" . "szermatt@gmx.net")))
